# Welcome to the Blue API Python SDK

This SDK is designed to facilitate interaction with the Blue API, enabling you to use Blue API endpoints in your Python projects.

We're in the early stages of development, so expect frequent updates and improvements. We only have a few endpoints available at the moment, but we'll be adding more over time to make it easier to manage your Blue environment programmatically.

Currently, we support the following endpoints:

- **get_project_list**: List all projects (name and id)
- **get_project_list_full_details**:  List all projects (full details)
- **create_project**: Create a new project 
- **get_records_company**: Get all records across a company

Stay Productive,

Team Blue